@@ -1,6 +1,10 @@
 """Provide the Auth class."""
-from prawcore import (Authorizer, ImplicitAuthorizer, TrustedAuthenticator,
-                      UntrustedAuthenticator, session)
+from prawcore import (
+    Authorizer,
+    ImplicitAuthorizer,
+    UntrustedAuthenticator,
+    session,
+)
 
 from .base import PRAWBase
 from ..exceptions import ClientException
@@ -17,15 +21,26 @@ class Auth(PRAWBase):
 
         :remaining: The number of requests remaining to be made in the
             current rate limit window.
+        :reset_timestamp: A unix timestamp providing an upper bound on when the
+            rate limit counters will reset.
         :used: The number of requests made in the current rate limit
             window.
 
-        Both values are initially ``None`` as these values are set in response
+        All values are initially ``None`` as these values are set in response
         to issued requests.
 
+        The ``reset_timestamp`` value is an upper bound as the real timestamp
+        is computed on Reddit's end in preparation for sending the
+        response. This value may change slightly within a given window due to
+        slight changes in response times and rounding.
+
         """
         data = self._reddit._core._rate_limiter
-        return {'remaining': data.remaining, 'used': data.used}
+        return {
+            "remaining": data.remaining,
+            "reset_timestamp": data.reset_timestamp,
+            "used": data.used,
+        }
 
     def authorize(self, code):
         """Complete the web authorization flow and return the refresh token.
@@ -37,9 +52,6 @@ class Auth(PRAWBase):
 
         """
         authenticator = self._reddit._read_only_core._authorizer._authenticator
-        if not isinstance(authenticator, TrustedAuthenticator) or \
-           self._reddit.config.username:
-            raise ClientException('authorize can only be used with web apps.')
         authorizer = Authorizer(authenticator)
         authorizer.authorize(code)
         authorized_session = session(authorizer)
@@ -58,16 +70,18 @@ class Auth(PRAWBase):
         :param scope: A space-delimited string of Reddit OAuth2 scope names as
             returned from Reddit's callback.
 
-        Raise class:`.ClientException` if :class:`.Reddit` was initialized for
+        Raise :class:`.ClientException` if :class:`.Reddit` was initialized for
         a non-installed application type.
 
         """
         authenticator = self._reddit._read_only_core._authorizer._authenticator
         if not isinstance(authenticator, UntrustedAuthenticator):
-            raise ClientException('implicit can only be used with installed '
-                                  'apps.')
-        implicit_session = session(ImplicitAuthorizer(
-            authenticator, access_token, expires_in, scope))
+            raise ClientException(
+                "implicit can only be used with installed apps."
+            )
+        implicit_session = session(
+            ImplicitAuthorizer(authenticator, access_token, expires_in, scope)
+        )
         self._reddit._core = self._reddit._authorized_core = implicit_session
 
     def scopes(self):
@@ -81,7 +95,7 @@ class Auth(PRAWBase):
             authorizer.refresh()
         return authorizer.scopes
 
-    def url(self, scopes, state, duration='permanent', implicit=False):
+    def url(self, scopes, state, duration="permanent", implicit=False):
         """Return the URL used out-of-band to grant access to your application.
 
         :param scopes: A list of OAuth scopes to request authorization for.
@@ -102,12 +116,16 @@ class Auth(PRAWBase):
         """
         authenticator = self._reddit._read_only_core._authorizer._authenticator
         if authenticator.redirect_uri is self._reddit.config.CONFIG_NOT_SET:
-            raise ClientException('redirect_uri must be provided')
+            raise ClientException("redirect_uri must be provided")
         if isinstance(authenticator, UntrustedAuthenticator):
             return authenticator.authorize_url(
-                'temporary' if implicit else duration, scopes, state,
-                implicit=implicit)
-        elif implicit:
-            raise ClientException('implicit can only be set for installed '
-                                  'applications')
+                "temporary" if implicit else duration,
+                scopes,
+                state,
+                implicit=implicit,
+            )
+        if implicit:
+            raise ClientException(
+                "implicit can only be set for installed applications"
+            )
         return authenticator.authorize_url(duration, scopes, state)
