@@ -1,5 +1,6 @@
 """Provide the SubredditListingMixin class."""
 from ....compat import urljoin
+from ....util.cache import cachedproperty
 from ...base import PRAWBase
 from ..generator import ListingGenerator
 from .base import BaseListingMixin
@@ -12,7 +13,7 @@ class SubredditListingMixin(
 ):
     """Adds additional methods pertaining to Subreddit-like instances."""
 
-    @property
+    @cachedproperty
     def comments(self):
         """Provide an instance of :class:`.CommentHelper`.
 
@@ -25,9 +26,7 @@ class SubredditListingMixin(
                print(comment.author)
 
         """
-        if self._comments is None:
-            self._comments = CommentHelper(self)
-        return self._comments
+        return CommentHelper(self)
 
     def __init__(self, reddit, _data):
         """Initialize a SubredditListingMixin instance.
@@ -36,7 +35,6 @@ class SubredditListingMixin(
 
         """
         super(SubredditListingMixin, self).__init__(reddit, _data=_data)
-        self._comments = None
 
 
 class CommentHelper(PRAWBase):
@@ -48,7 +46,7 @@ class CommentHelper(PRAWBase):
 
     def __init__(self, subreddit):
         """Initialize a CommentHelper instance."""
-        super(CommentHelper, self).__init__(subreddit._reddit, None)
+        super(CommentHelper, self).__init__(subreddit._reddit, _data=None)
         self.subreddit = subreddit
 
     def __call__(self, **generator_kwargs):
@@ -66,18 +64,3 @@ class CommentHelper(PRAWBase):
 
         """
         return ListingGenerator(self._reddit, self._path, **generator_kwargs)
-
-    def gilded(self, **generator_kwargs):
-        """Deprecated.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 6 because
-                     it doesn't actually restrict the results to gilded
-                     Comments. Use ``subreddit.gilded`` instead.
-
-        Additional keyword arguments are passed in the initialization of
-        :class:`.ListingGenerator`.
-
-        """
-        return ListingGenerator(
-            self._reddit, urljoin(self._path, "gilded"), **generator_kwargs
-        )
