@@ -1,5 +1,6 @@
 """Provide the LiveThread class."""
 from ...const import API_PATH
+from ...util.cache import cachedproperty
 from ..listing.generator import ListingGenerator
 from ..list.redditor import RedditorList
 from .base import RedditBase
@@ -269,7 +270,7 @@ class LiveThread(RedditBase):
 
     STR_FIELD = "id"
 
-    @property
+    @cachedproperty
     def contrib(self):
         """Provide an instance of :class:`.LiveThreadContribution`.
 
@@ -281,11 +282,9 @@ class LiveThread(RedditBase):
            thread.contrib.add('### update')
 
         """
-        if self._contrib is None:
-            self._contrib = LiveThreadContribution(self)
-        return self._contrib
+        return LiveThreadContribution(self)
 
-    @property
+    @cachedproperty
     def contributor(self):
         """Provide an instance of :class:`.LiveContributorRelationship`.
 
@@ -302,9 +301,7 @@ class LiveThread(RedditBase):
                print(contributor, contributor.permissions)
 
         """
-        if self._contributor is None:
-            self._contributor = LiveContributorRelationship(self)
-        return self._contributor
+        return LiveContributorRelationship(self)
 
     def __eq__(self, other):
         """Return whether the other instance equals the current.
@@ -350,11 +347,21 @@ class LiveThread(RedditBase):
         super(LiveThread, self).__init__(reddit, _data=_data)
         if id:
             self.id = id  # pylint: disable=invalid-name
-        self._contrib = None
-        self._contributor = None
 
-    def _info_path(self):
-        return API_PATH["liveabout"].format(id=self.id)
+    def _fetch_info(self):
+        return ("liveabout", {"id": self.id}, None)
+
+    def _fetch_data(self):
+        name, fields, params = self._fetch_info()
+        path = API_PATH[name].format(**fields)
+        return self._reddit.request("GET", path, params)
+
+    def _fetch(self):
+        data = self._fetch_data()
+        data = data["data"]
+        other = type(self)(self._reddit, _data=data)
+        self.__dict__.update(other.__dict__)
+        self._fetched = True
 
     def discussions(self, **generator_kwargs):
         """Get submissions linking to the thread.
@@ -558,8 +565,9 @@ class LiveUpdate(FullnameMixin, RedditBase):
     """
 
     STR_FIELD = "id"
+    _kind = "LiveUpdate"
 
-    @property
+    @cachedproperty
     def contrib(self):
         """Provide an instance of :class:`.LiveUpdateContribution`.
 
@@ -572,9 +580,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
            update.contrib  # LiveUpdateContribution instance
 
         """
-        if self._contrib is None:
-            self._contrib = LiveUpdateContribution(self)
-        return self._contrib
+        return LiveUpdateContribution(self)
 
     @property
     def thread(self):
@@ -609,7 +615,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
             super(LiveUpdate, self).__init__(reddit, _data=_data)
             self._fetched = True
         elif thread_id and update_id:
-            super(LiveUpdate, self).__init__(reddit, None)
+            super(LiveUpdate, self).__init__(reddit, _data=None)
             self._thread = LiveThread(self._reddit, thread_id)
             self.id = update_id  # pylint: disable=invalid-name
         else:
@@ -617,7 +623,6 @@ class LiveUpdate(FullnameMixin, RedditBase):
                 "Either `thread_id` and `update_id`, or "
                 "`_data` must be provided."
             )
-        self._contrib = None
 
     def __setattr__(self, attribute, value):
         """Objectify author."""
