@@ -3,6 +3,7 @@ from json import dumps
 import re
 
 from ...const import API_PATH
+from ...util.cache import cachedproperty
 from ..listing.mixins import SubredditListingMixin
 from .base import RedditBase
 from .redditor import Redditor
@@ -44,7 +45,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
     """
 
     STR_FIELD = "path"
-    RE_INVALID = re.compile(r"(\s|\W|_)+", re.UNICODE)
+    RE_INVALID = re.compile(r"[\W_]+", re.UNICODE)
 
     @staticmethod
     def sluggify(title):
@@ -63,7 +64,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
                 title = title[:last_word]
         return title or "_"
 
-    @property
+    @cachedproperty
     def stream(self):
         """Provide an instance of :class:`.SubredditStream`.
 
@@ -86,9 +87,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
                print(submission)
 
         """
-        if self._stream is None:
-            self._stream = SubredditStream(self)
-        return self._stream
+        return SubredditStream(self)
 
     def __init__(self, reddit, _data):
         """Construct an instance of the Multireddit object."""
@@ -98,18 +97,31 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self._path = API_PATH["multireddit"].format(
             multi=self.name, user=self._author
         )
-        self._stream = None
         self.path = "/" + self._path[:-1]  # Prevent requests for path
         if "subreddits" in self.__dict__:
             self.subreddits = [
                 Subreddit(reddit, x["name"]) for x in self.subreddits
             ]
 
-    def _info_path(self):
-        return API_PATH["multireddit_api"].format(
-            multi=self.name, user=self._author
+    def _fetch_info(self):
+        return (
+            "multireddit_api",
+            {"multi": self.name, "user": self._author.name},
+            None,
         )
 
+    def _fetch_data(self):
+        name, fields, params = self._fetch_info()
+        path = API_PATH[name].format(**fields)
+        return self._reddit.request("GET", path, params)
+
+    def _fetch(self):
+        data = self._fetch_data()
+        data = data["data"]
+        other = type(self)(self._reddit, _data=data)
+        self.__dict__.update(other.__dict__)
+        self._fetched = True
+
     def add(self, subreddit):
         """Add a subreddit to this multireddit.
 
@@ -149,7 +161,10 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
     def delete(self):
         """Delete this multireddit."""
-        self._reddit.request("DELETE", self._info_path())
+        path = API_PATH["multireddit_api"].format(
+            multi=self.name, user=self._author.name
+        )
+        self._reddit.request("DELETE", path)
 
     def remove(self, subreddit):
         """Remove a subreddit from this multireddit.
@@ -202,8 +217,11 @@ class Multireddit(SubredditListingMixin, RedditBase):
             updated_settings["subreddits"] = [
                 {"name": str(sub)} for sub in updated_settings["subreddits"]
             ]
+        path = API_PATH["multireddit_api"].format(
+            multi=self.name, user=self._author.name
+        )
         response = self._reddit.request(
-            "PUT", self._info_path(), data={"model": dumps(updated_settings)}
+            "PUT", path, data={"model": dumps(updated_settings)}
         )
         new = Multireddit(self._reddit, response["data"])
         self.__dict__.update(new.__dict__)
