@@ -2,6 +2,7 @@
 from json import dumps
 
 from ...const import API_PATH
+from ...util.cache import cachedproperty
 from ..listing.mixins import RedditorListingMixin
 from ..util import stream_generator
 from .base import RedditBase
@@ -72,7 +73,7 @@ class Redditor(
             return None
         return cls(reddit, data)
 
-    @property
+    @cachedproperty
     def stream(self):
         """Provide an instance of :class:`.RedditorStream`.
 
@@ -94,9 +95,12 @@ class Redditor(
                print(submission)
 
         """
-        if self._stream is None:
-            self._stream = RedditorStream(self)
-        return self._stream
+        return RedditorStream(self)
+
+    @property
+    def _kind(self):
+        """Return the class's kind."""
+        return self._reddit.config.kinds["redditor"]
 
     def __init__(self, reddit, name=None, _data=None):
         """Initialize a Redditor instance.
@@ -116,10 +120,21 @@ class Redditor(
         if name:
             self.name = name
         self._path = API_PATH["user"].format(user=self)
-        self._stream = None
 
-    def _info_path(self):
-        return API_PATH["user_about"].format(user=self)
+    def _fetch_info(self):
+        return ("user_about", {"user": self.name}, None)
+
+    def _fetch_data(self):
+        name, fields, params = self._fetch_info()
+        path = API_PATH[name].format(**fields)
+        return self._reddit.request("GET", path, params)
+
+    def _fetch(self):
+        data = self._fetch_data()
+        data = data["data"]
+        other = type(self)(self._reddit, _data=data)
+        self.__dict__.update(other.__dict__)
+        self._fetched = True
 
     def _friend(self, method, data):
         url = API_PATH["friend_v1"].format(user=self)
