@@ -2,7 +2,9 @@
 from ...compat import urljoin
 from ...const import API_PATH
 from ...exceptions import ClientException
+from ...util.cache import cachedproperty
 from ..comment_forest import CommentForest
+from ..listing.listing import Listing
 from ..listing.mixins import SubmissionListingMixin
 from .base import RedditBase
 from .mixins import FullnameMixin, ThingModerationMixin, UserContentMixin
@@ -96,6 +98,11 @@ class Submission(
             raise ClientException("Invalid URL: {}".format(url))
         return submission_id
 
+    @property
+    def _kind(self):
+        """Return the class's kind."""
+        return self._reddit.config.kinds["submission"]
+
     @property
     def comments(self):
         """Provide an instance of :class:`.CommentForest`.
@@ -124,7 +131,7 @@ class Submission(
         # This assumes _comments is set so that _fetch is called when it's not.
         return self._comments
 
-    @property
+    @cachedproperty
     def flair(self):
         """Provide an instance of :class:`.SubmissionFlair`.
 
@@ -143,16 +150,12 @@ class Submission(
            submission.flair.select(template_id, 'my custom value')
 
         """
-        if self._flair is None:
-            self._flair = SubmissionFlair(self)
-        return self._flair
+        return SubmissionFlair(self)
 
-    @property
+    @cachedproperty
     def mod(self):
         """Provide an instance of :class:`.SubmissionModeration`."""
-        if self._mod is None:
-            self._mod = SubmissionModeration(self)
-        return self._mod
+        return SubmissionModeration(self)
 
     @property
     def shortlink(self):
@@ -188,14 +191,13 @@ class Submission(
         super(Submission, self).__init__(reddit, _data=_data)
         self.comment_limit = 2048
 
-        #: Specify the sort order for ``comments``
+        # Specify the sort order for ``comments``
         self.comment_sort = "best"
 
         if id is not None:
             self.id = id  # pylint: disable=invalid-name
         elif url is not None:
             self.id = self.id_from_url(url)
-        self._flair = self._mod = None
 
         self._comments_by_id = {}
 
@@ -215,21 +217,33 @@ class Submission(
         for position in range(0, len(all_submissions), chunk_size):
             yield ",".join(all_submissions[position : position + 50])
 
-    def _fetch(self):
-        other, comments = self._reddit.get(
-            self._info_path(),
-            params={"limit": self.comment_limit, "sort": self.comment_sort},
+    def _fetch_info(self):
+        return (
+            "submission",
+            {"id": self.id},
+            {"limit": self.comment_limit, "sort": self.comment_sort},
         )
-        other = other.children[0]
-        delattr(other, "comment_limit")
-        delattr(other, "comment_sort")
-        other._comments = CommentForest(self)
-        self.__dict__.update(other.__dict__)
-        self.comments._update(comments.children)
-        self._fetched = True
 
-    def _info_path(self):
-        return API_PATH["submission"].format(id=self.id)
+    def _fetch_data(self):
+        name, fields, params = self._fetch_info()
+        path = API_PATH[name].format(**fields)
+        return self._reddit.request("GET", path, params)
+
+    def _fetch(self):
+        data = self._fetch_data()
+        submission_listing, comment_listing = data
+        comment_listing = Listing(self._reddit, _data=comment_listing["data"])
+
+        submission_data = submission_listing["data"]["children"][0]["data"]
+        submission = type(self)(self._reddit, _data=submission_data)
+        delattr(submission, "comment_limit")
+        delattr(submission, "comment_sort")
+        submission._comments = CommentForest(self)
+
+        self.__dict__.update(submission.__dict__)
+        self.comments._update(comment_listing.children)
+
+        self._fetched = True
 
     def mark_visited(self):
         """Mark submission as visited.
@@ -464,23 +478,6 @@ class SubmissionModeration(ThingModerationMixin):
         url = API_PATH["flair"].format(subreddit=self.thing.subreddit)
         self.thing._reddit.post(url, data=data)
 
-    def lock(self):
-        """Lock the submission.
-
-        Example usage:
-
-        .. code:: python
-
-           submission = reddit.submission(id='5or86n')
-           submission.mod.lock()
-
-        See also :meth:`~.unlock`
-
-        """
-        self.thing._reddit.post(
-            API_PATH["lock"], data={"id": self.thing.fullname}
-        )
-
     def nsfw(self):
         """Mark as not safe for work.
 
@@ -581,23 +578,6 @@ class SubmissionModeration(ThingModerationMixin):
             data={"id": self.thing.fullname, "sort": sort},
         )
 
-    def unlock(self):
-        """Unlock the submission.
-
-        Example:
-
-        .. code:: python
-
-           submission = reddit.submission(id='5or86n')
-           submission.mod.unlock()
-
-        See also :meth:`~.lock`
-
-        """
-        self.thing._reddit.post(
-            API_PATH["unlock"], data={"id": self.thing.fullname}
-        )
-
     def unspoiler(self):
         """Indicate that the submission does not contain spoilers.
 
