@@ -1,5 +1,6 @@
 """Provide the WikiPage class."""
 from ...const import API_PATH
+from ...util.cache import cachedproperty
 from ..listing.generator import ListingGenerator
 from .base import RedditBase
 from .redditor import Redditor
@@ -49,12 +50,10 @@ class WikiPage(RedditBase):
             )
             yield revision
 
-    @property
+    @cachedproperty
     def mod(self):
         """Provide an instance of :class:`.WikiPageModeration`."""
-        if self._mod is None:
-            self._mod = WikiPageModeration(self)
-        return self._mod
+        return WikiPageModeration(self)
 
     def __eq__(self, other):
         """Return whether the other instance equals the current."""
@@ -74,7 +73,6 @@ class WikiPage(RedditBase):
         self._revision = revision
         self.subreddit = subreddit
         super(WikiPage, self).__init__(reddit, _data=_data)
-        self._mod = None
 
     def __repr__(self):
         """Return an object initialization representation of the instance."""
@@ -86,9 +84,21 @@ class WikiPage(RedditBase):
         """Return a string representation of the instance."""
         return "{}/{}".format(self.subreddit, self.name)
 
+    def _fetch_info(self):
+        return (
+            "wiki_page",
+            {"subreddit": self.subreddit, "page": self.name},
+            {"v": self._revision} if self._revision else None,
+        )
+
+    def _fetch_data(self):
+        name, fields, params = self._fetch_info()
+        path = API_PATH[name].format(**fields)
+        return self._reddit.request("GET", path, params)
+
     def _fetch(self):
-        params = {"v": self._revision} if self._revision else None
-        data = self._reddit.get(self._info_path(), params=params)["data"]
+        data = self._fetch_data()
+        data = data["data"]
         if data["revision_by"] is not None:
             data["revision_by"] = Redditor(
                 self._reddit, _data=data["revision_by"]["data"]
@@ -96,11 +106,6 @@ class WikiPage(RedditBase):
         self.__dict__.update(data)
         self._fetched = True
 
-    def _info_path(self):
-        return API_PATH["wiki_page"].format(
-            subreddit=self.subreddit, page=self.name
-        )
-
     def edit(self, content, reason=None, **other_settings):
         """Edit this WikiPage's contents.
 
