@@ -1,55 +1,56 @@
 """Provides the Objector class."""
-import re
-
-from .exceptions import APIException
+from .exceptions import APIException, ClientException
+from .util import snake_case_keys
 
 
 class Objector(object):
     """The objector builds :class:`.RedditBase` objects."""
 
-    @staticmethod
-    def _camel_to_snake(name):
-        """Return `name` converted from camelCase to snake_case.
+    @classmethod
+    def parse_error(cls, data):
+        """Convert JSON response into an error object.
 
-        Code from http://stackoverflow.com/a/1176023/.
+        :param data: The dict to be converted.
+        :returns: An instance of :class:`~.APIException`, or ``None`` if
+            ``data`` doesn't fit this model.
 
         """
-        first_break_replaced = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", name)
-        return re.sub(
-            "([a-z0-9])([A-Z])", r"\1_\2", first_break_replaced
-        ).lower()
+        if isinstance(data, list):
+            # Fetching a Submission returns a list (of two items).
+            # Although it's handled manually in `Submission._fetch()`,
+            # assume it's a possibility here.
+            return None
+
+        errors = data.get("json", {}).get("errors")
+        if errors is None:
+            return None
+        if len(errors) < 1:
+            # See `Collection._fetch()`.
+            raise ClientException("successful error response", data)
+        if len(errors) > 1:
+            # Yet to be observed.
+            raise AssertionError(
+                "multiple error descriptions in response", data
+            )
+
+        return APIException(*errors[0])
 
     @classmethod
-    def _snake_case_keys(cls, dictionary):
-        """Return a copy of dictionary with keys converted to snake_case.
+    def check_error(cls, data):
+        """Raise an error if the argument resolves to an error object."""
+        error = cls.parse_error(data)
+        if error:
+            raise error
 
-        :param dictionary: The dict to be corrected.
-
-        """
-        return {cls._camel_to_snake(k): v for k, v in dictionary.items()}
-
-    def __init__(self, reddit):
+    def __init__(self, reddit, parsers=None):
         """Initialize an Objector instance.
 
         :param reddit: An instance of :class:`~.Reddit`.
 
         """
-        self.parsers = {}
+        self.parsers = {} if parsers is None else parsers
         self._reddit = reddit
 
-    def kind(self, instance):
-        """Return the kind from the instance class.
-
-        :param instance: An instance of a subclass of RedditBase.
-
-        """
-        retval = None
-        for key in self.parsers:
-            if isinstance(instance, self.parsers[key]):
-                retval = key
-                break
-        return retval
-
     def _objectify_dict(self, data):
         """Create RedditBase objects from dicts.
 
@@ -61,27 +62,27 @@ class Objector(object):
             parser = self.parsers["ModmailConversation"]
         elif {"actionTypeId", "author", "date"}.issubset(data):
             # Modmail mod action
-            data = self._snake_case_keys(data)
+            data = snake_case_keys(data)
             parser = self.parsers["ModmailAction"]
         elif {"bodyMarkdown", "isInternal"}.issubset(data):
             # Modmail message
-            data = self._snake_case_keys(data)
+            data = snake_case_keys(data)
             parser = self.parsers["ModmailMessage"]
         elif {"isAdmin", "isDeleted"}.issubset(data):
             # Modmail author
-            data = self._snake_case_keys(data)
+            data = snake_case_keys(data)
             # Prevent clobbering base-36 id
             del data["id"]
             data["is_subreddit_mod"] = data.pop("is_mod")
             parser = self.parsers[self._reddit.config.kinds["redditor"]]
         elif {"banStatus", "muteStatus", "recentComments"}.issubset(data):
             # Modmail user
-            data = self._snake_case_keys(data)
+            data = snake_case_keys(data)
             data["created_string"] = data.pop("created")
             parser = self.parsers[self._reddit.config.kinds["redditor"]]
         elif {"displayName", "id", "type"}.issubset(data):
             # Modmail subreddit
-            data = self._snake_case_keys(data)
+            data = snake_case_keys(data)
             parser = self.parsers[self._reddit.config.kinds[data["type"]]]
         elif {"date", "id", "name"}.issubset(data) or {
             "id",
@@ -106,6 +107,8 @@ class Objector(object):
             return self._reddit.redditor(data["name"])
         elif {"parent_id"}.issubset(data):
             parser = self.parsers[self._reddit.config.kinds["comment"]]
+        elif "collection_id" in data.keys():
+            parser = self.parsers["Collection"]
         else:
             if "user" in data:
                 parser = self.parsers[self._reddit.config.kinds["redditor"]]
@@ -158,12 +161,3 @@ class Objector(object):
             return self._objectify_dict(data)
 
         return data
-
-    def register(self, kind, cls):
-        """Register a class for a given kind.
-
-        :param kind: The kind in the parsed data to map to ``cls``.
-        :param cls: A RedditBase class.
-
-        """
-        self.parsers[kind] = cls
